Version 0.3.1 (2024-04-17)
==========================

- Small fixes with datatypes

Version 0.3.0 (2024-04-15)
==========================

- added distance measures for most_similar: count, jaccard and weighted_jaccard
- restructured code for performance and readability
- separated Python bindings (in PYSELMR) and SELMR struct

Version 0.2.0 (2024-03-24)
==========================

- internal data structure changed to HashMap for phrases and contexts with IndexMap for counters
- zip file as output added

Version 0.1.0 (2024-03-10)
==========================

- Initial version
